@@ -10,13 +10,13 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+from urllib import parse
 
 from keystoneclient.contrib.ec2 import utils as ec2_utils
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
 from oslo_utils import timeutils
-from six.moves.urllib import parse as urlparse
 
 from heat.common import exception
 from heat.common.i18n import _
@@ -107,7 +107,7 @@ class SignalResponder(stack_user.StackUser):
             if self.password is None:
                 self.password = password_gen.generate_openstack_password()
             self._create_user()
-        return {'auth_url':  self.keystone().server_keystone_endpoint_url(
+        return {'auth_url': self.keystone().server_keystone_endpoint_url(
                 fallback_endpoint=self.keystone().v3_endpoint),
                 'username': self.physical_resource_name(),
                 'user_id': self._get_user_id(),
@@ -152,7 +152,7 @@ class SignalResponder(stack_user.StackUser):
             endpoint = heat_client_plugin.get_heat_cfn_url()
             signal_url = ''.join([endpoint, signal_type])
 
-        host_url = urlparse.urlparse(signal_url)
+        host_url = parse.urlparse(signal_url)
 
         path = self.identifier().arn_url_path()
 
@@ -160,7 +160,7 @@ class SignalResponder(stack_user.StackUser):
         # processing in the CFN API (ec2token.py) has an unquoted path, so we
         # need to calculate the signature with the path component unquoted, but
         # ensure the actual URL contains the quoted version...
-        unquoted_path = urlparse.unquote(host_url.path + path)
+        unquoted_path = parse.unquote(host_url.path + path)
         params = {'SignatureMethod': 'HmacSHA256',
                   'SignatureVersion': '2',
                   'AWSAccessKeyId': access_key}
@@ -175,7 +175,7 @@ class SignalResponder(stack_user.StackUser):
         signer = ec2_utils.Ec2Signer(secret_key)
         request['params']['Signature'] = signer.generate(request)
 
-        qs = urlparse.urlencode(request['params'])
+        qs = parse.urlencode(request['params'])
         url = "%s%s?%s" % (signal_url.lower(),
                            path, qs)
 
@@ -206,7 +206,7 @@ class SignalResponder(stack_user.StackUser):
         if project_id is not None:
             path = project_id + path[path.find('/'):]
 
-        url = urlparse.urljoin(url, '%s/signal' % path)
+        url = parse.urljoin(url, '%s/signal' % path)
 
         self.data_set('heat_signal_url', url)
         return url
