@@ -1387,6 +1387,11 @@ class Stack(collections.abc.Mapping):
         Update will fail if it exceeds the specified timeout. The default is
         60 minutes, set in the constructor
         """
+        # Populate resource data needed for calulating frozen definitions
+        # (particularly for metadata, which doesn't get stored separately).
+        self._update_all_resource_data(for_resources=True,
+                                       for_outputs=False)
+
         self.updated_time = oslo_timeutils.utcnow()
         updater = scheduler.TaskRunner(self.update_task, newstack,
                                        msg_queue=msg_queue, notify=notify)
@@ -1884,11 +1889,13 @@ class Stack(collections.abc.Mapping):
     def _try_get_user_creds(self):
         # There are cases where the user_creds cannot be returned
         # due to credentials truncated when being saved to DB.
-        # Ignore this error instead of blocking stack deletion.
+        # Also, there are cases where auth_encryption_key has
+        # changed for some reason.
+        # Ignore these errors instead of blocking stack deletion.
         try:
             return ucreds_object.UserCreds.get_by_id(self.context,
                                                      self.user_creds_id)
-        except exception.Error:
+        except (exception.Error, exception.InvalidEncryptionKey):
             LOG.exception("Failed to retrieve user_creds")
             return None
 
